@@ -36,11 +36,9 @@ class EnergySystemHandler:
         setattr(EObject, 'deepcopy', support_functions.deepcopy)
 
 
-        # have a nice __repr__ for some ESDL classes when printing ESDL objects (includes all Assets and EnergyAssets)
+        # have a nice __repr__ for the EnergySystem class when printing. As most objects are linked together
+        # we don't do this for other classes, due to recursion.
         esdl.EnergySystem.__repr__ = lambda x: '{}({})'.format(type(x).__name__, EnergySystemHandler.attr_to_dict(x))
-        esdl.EnergyAsset.__repr__ = lambda x: '{}({})'.format(type(x).__name__, EnergySystemHandler.attr_to_dict(x))
-        esdl.Instance.__repr__ = lambda x: '{}({})'.format(type(x).__name__, EnergySystemHandler.attr_to_dict(x))
-        esdl.Area.__repr__ = lambda x: '{}({})'.format(type(x).__name__, EnergySystemHandler.attr_to_dict(x))
 
     def _new_resource_set(self):
         """Resets the resourceset (e.g. when loading a new file)"""
@@ -49,14 +47,14 @@ class EnergySystemHandler:
         # Assign files with the .esdl extension to the XMLResource instead of default XMI
         self.rset.resource_factory['esdl'] = lambda uri: XMLResource(uri)
 
-    def load_file(self, uri_or_filename):
+    def load_file(self, uri_or_filename: str) -> esdl.EnergySystem:
         if uri_or_filename[:4] == 'http':
             uri = HttpURI(uri_or_filename)
         else:
             uri = URI(uri_or_filename)
         return self.load_uri(uri)
 
-    def load_uri(self, uri):
+    def load_uri(self, uri) -> esdl.EnergySystem:
         """Loads a new resource in a new resourceSet"""
         self._new_resource_set()
         self.resource = self.rset.get_resource(uri)
@@ -64,14 +62,14 @@ class EnergySystemHandler:
         self.energy_system = self.resource.contents[0]
         return self.energy_system
 
-    def add_uri(self, uri):
+    def add_uri(self, uri) -> esdl.EnergySystem:
         """Adds the specified URI to the resource set, i.e. load extra resources that the resource can refer to."""
         self.resource = self.rset.get_resource(uri)
         # At this point, the model instance is loaded!
         self.energy_system = self.resource.contents[0]
         return self.energy_system
 
-    def load_from_string(self, esdl_string):
+    def load_from_string(self, esdl_string) -> esdl.EnergySystem:
         uri = StringURI('from_string.esdl', esdl_string)
         # self._new_resource_set()
         self.resource = self.rset.create_resource(uri)
@@ -79,14 +77,14 @@ class EnergySystemHandler:
         self.energy_system = self.resource.contents[0]
         return self.energy_system
 
-    def to_string(self):
+    def to_string(self) -> str:
         # to use strings as resources, we simulate a string as being a URI
         uri = StringURI('to_string.esdl')
         self.resource.save(uri)
         # return the string
         return uri.getvalue()
 
-    def to_bytesio(self):
+    def to_bytesio(self) -> BytesIO:
         """Returns a BytesIO stream for the energy system"""
         uri = StringURI('to_string.esdl')
         self.resource.save(uri)
@@ -109,14 +107,14 @@ class EnergySystemHandler:
         """Saves the resource under a different filename"""
         self.resource.save(output=filename)
 
-    def get_energy_system(self):
+    def get_energy_system(self) -> esdl.EnergySystem:
         return self.energy_system
 
     # Using this function you can query for objects by ID
     # When loading an ESDL-file, all objects that have an ID defined are stored in resource.uuid_dict automatically
     # Note: If you add things later to the resource, it won't be added automatically to this dictionary though.
     # Use get_by_id_slow() for that
-    def get_by_id(self, object_id):
+    def get_by_id(self, object_id) -> EObject:
         if object_id in self.resource.uuid_dict:
             return self.resource.uuid_dict[object_id]
         else:
@@ -139,13 +137,6 @@ class EnergySystemHandler:
     def remove_asset_by_id(self, asset_id):
         del self.resource.uuid_dict[asset_id]
 
-    # returns a generator of all assets of a specific type. Not only the ones defined in  the main Instance's Area
-    # e.g. QuantityAndUnits can be defined in the KPI of an Area or in the EnergySystemInformation object
-    # this function returns all of them at once
-    @staticmethod
-    def get_all_assets_of_type(self, esdl_type):
-        return esdl_type.allInstances()
-
     # Creates a dict of all the attributes of an ESDL object, useful for printing/debugging
     @staticmethod
     def attr_to_dict(esdl_object):
@@ -157,12 +148,12 @@ class EnergySystemHandler:
                 d[attr] = attr_value
         return d
 
-    # Creates a uuid: useful for generating unique IDs
     @staticmethod
     def generate_uuid():
+        ''' Creates a uuid: useful for generating unique IDs'''
         return str(uuid4())
 
-    def create_empty_energy_system(self, name, es_description, inst_title, area_title):
+    def create_empty_energy_system(self, name, es_description, inst_title, area_title) -> esdl.EnergySystem:
         es_id = self.generate_uuid()
         self.energy_system = esdl.EnergySystem(id=es_id, name=name, description=es_description)
 
